Tutorials — PyEPR 1.0.0 documentation

# Tutorials

- Interactive use of PyEPR
  - `epr` module and classes
  - `epr.Product` navigation
  - Iterating over `epr` objects
  - Image data
  - Closing the epr.Product
- Exporting band data
  - Import section
  - The main program
  - The `write_raw_image()` core function
- Exporting bitmasks
- NDVI computation
- Update `Field` elements
- GDAL export example
  - export_gdalvrt module
  - Generating VRTRawRasterBands
  - Metadata
  - Complete listing